%define ALD_Ver		1.2.4

Name:         cups-pdf

License:      GPLv2
Summary:      PDF writer backend for CUPS
Group:        System Environment/Daemons
Version:      2.6.1
Release:      1

#https://pawn.physik.uni-wuerzburg.de/~vrbehr/cups-pdf/src/

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/ps_pdf_printer
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-%{_os}%{_gnu}
%define target_  %{nil}

%endif # !_CROSS || !TARGETBUILD_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
PDF writer backend for CUPS

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
sed -i s:"#Out /var/spool/cups-pdf/\${USER}":"Out \${HOME}/PDF": extra/cups-pdf.conf
sed -i s:"#DecodeHexStrings 0":"DecodeHexStrings 1": extra/cups-pdf.conf

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`
OPT47=`case $GCC_VER_STR in 4.[789].*|5.*) echo "-fno-asynchronous-unwind-tables -fno-dwarf2-cfi-asm" ;; esac`

%if %{_arch} == "i386"
case $GCC_VER_STR in
  4.9.*|5.*) OPTFLAGS="-O2 -march=i586" ;;
  *)     OPTFLAGS="-O2 -march=i486" ;;
esac
OPTFLAGS="$OPTFLAGS -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer $OPT47"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 $OPT47"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access $OPT47"
%endif


OPTFLAGS="$OPTFLAGS -fno-stack-protector -std=gnu99"

cd src
gcc $OPTFLAGS -o cups-pdf cups-pdf.c
cd ..

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/cups
cp extra/cups-pdf.conf $RPM_BUILD_ROOT/%{_sysconfdir}/cups/cups-pdf.conf.default

mkdir -p $RPM_BUILD_ROOT%{_libdir}/cups/backend
cp src/cups-pdf $RPM_BUILD_ROOT%{_libdir}/cups/backend/
chmod 0700 $RPM_BUILD_ROOT%{_libdir}/cups/backend/cups-pdf

mkdir -p $RPM_BUILD_ROOT%{_datadir}/cups/model
cp extra/CUPS-PDF.ppd $RPM_BUILD_ROOT%{_datadir}/cups/model/

mkdir -p $RPM_BUILD_ROOT%{docdir}
cp COPYING README $RPM_BUILD_ROOT%{docdir}/

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/spool/cups-pdf/ANONYMOUS
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/spool/cups-pdf/SPOOL


%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

%post
if test ! -e /etc/cups/cups-pdf.conf; then
  cp /etc/cups/cups-pdf.conf.default /etc/cups/cups-pdf.conf
fi
chown root:lp /var/spool/cups-pdf
chown root:lp /var/spool/cups-pdf/ANONYMOUS
chmod 0777 /var/spool/cups-pdf/ANONYMOUS

# ------------------- Files ------------------------------------------
%Files
%{_sysconfdir}
%{_libdir}
%{_datadir}
%{_localstatedir}
